@@ -4,6 +4,10 @@ test_that("list_id_mapping_workflows", {
   expect_error(svc$list_id_mapping_workflows(), NA)
 })
 
+test_that("list_id_namespaces", {
+  expect_error(svc$list_id_namespaces(), NA)
+})
+
 test_that("list_matching_workflows", {
   expect_error(svc$list_matching_workflows(), NA)
 })
