@@ -8,6 +8,10 @@ test_that("list_playback_key_pairs", {
   expect_error(svc$list_playback_key_pairs(), NA)
 })
 
+test_that("list_playback_restriction_policies", {
+  expect_error(svc$list_playback_restriction_policies(), NA)
+})
+
 test_that("list_recording_configurations", {
   expect_error(svc$list_recording_configurations(), NA)
 })
